@@ -29,7 +29,8 @@
 #include "widgets.h"
 #include "credits_window.h"
 #include "show_help.h"
-#include "backup_buttons.h"
+#include "backup_and_restore.h"
+#include "restore_menu.h"
 
 
 
@@ -83,7 +84,7 @@ void create_main_window(struct w *widgets)
 
     gtk_toolbar_set_style(GTK_TOOLBAR(main_toolbar), GTK_TOOLBAR_BOTH);
 
-    /* Sync button */    
+    /* Run selected backup button */    
     GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes", 
                                   gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *backup_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
@@ -103,7 +104,18 @@ void create_main_window(struct w *widgets)
 							  NULL, NULL,
 							  toolbar_icon_no, NULL, NULL);
     g_signal_connect_swapped(G_OBJECT(cancel_backup_button), "clicked", 
-                             G_CALLBACK(cancel_backup_clicked), widgets);
+                             G_CALLBACK(cancel_process_clicked), widgets);
+
+    /* Restore selected backup button */
+    GtkWidget *toolbar_icon_restore = gtk_image_new_from_stock("gtk-yes", 
+                                      gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *restore_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
+                                                          GTK_TOOLBAR_CHILD_BUTTON,
+							  NULL, _("Restore from selection"),
+							  NULL, NULL,
+							  toolbar_icon_restore, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(restore_button), "clicked", 
+                             G_CALLBACK(show_restore_menu), widgets);
 
 
     /* Help button */
@@ -150,19 +162,19 @@ void create_main_window(struct w *widgets)
     widgets->notebook_vbox3 = gtk_vbox_new(FALSE, 0);
     widgets->notebook_vbox4 = gtk_vbox_new(FALSE, 0);
 
-    GtkWidget *main_notebook = gtk_notebook_new();
-    gtk_box_pack_start(GTK_BOX(notebook_vbox), main_notebook, TRUE, TRUE, 0);
-    gtk_notebook_set_show_border(GTK_NOTEBOOK(main_notebook), TRUE);
+    widgets->main_notebook = gtk_notebook_new();
+    gtk_box_pack_start(GTK_BOX(notebook_vbox), widgets->main_notebook, TRUE, TRUE, 0);
+    gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets->main_notebook), TRUE);
 
     GtkWidget *rsync_label = gtk_label_new(_("Backup settings"));
     GtkWidget *progress_label = gtk_label_new(_("Backup progress"));
     GtkWidget *disc_label = gtk_label_new(_("Disc"));
     GtkWidget *server_label = gtk_label_new(_("Server settings"));
 
-    gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox1, rsync_label, 0);
-    gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox2, progress_label, 1);
-    gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox3, disc_label, 2);
-    gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox4, server_label, 3);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(widgets->main_notebook), widgets->notebook_vbox1, rsync_label, 0);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(widgets->main_notebook), widgets->notebook_vbox2, progress_label, 1);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(widgets->main_notebook), widgets->notebook_vbox3, disc_label, 2);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(widgets->main_notebook), widgets->notebook_vbox4, server_label, 3);
 
 
     /* Set default version and status labels */
