@@ -37,7 +37,7 @@
 #include "save_backup_settings.h"
 #include "commands.h"
 #include "cron_functions.h"
-#include "add_backup_menu.h"
+#include "backup_menu.h"
 #include "show_log.h"
 
 
@@ -244,9 +244,9 @@ void delete_backup(struct w *widgets)
 	unlink(conf_file);
 	g_free(conf_file);
     }
-    
+
     /* Delete the schedule script if any */
-    script_file = mk_script_path(global_backup_name);
+    script_file = mk_backup_script_path(global_backup_name);
     if( script_file!=NULL && strstr(script_file, "gadmin-rsync") )
       unlink(script_file);
 
@@ -257,6 +257,12 @@ void delete_backup(struct w *widgets)
     if( script_file!=NULL )
       g_free(script_file);
 
+    /* Delete backup at shutdown link if any */
+    script_file = mk_backup_at_shutdown_script_path(global_backup_name);
+    remove_from_system_shutdown(global_backup_name);
+    if( script_file!=NULL )
+      g_free(script_file);
+
     /* Delete the log file if any */
     log_file = mk_log_path(global_backup_name);
     if( log_file!=NULL && strstr(log_file, "gadmin-rsync") )
@@ -293,8 +299,8 @@ void create_new_backup_window(struct w *widgets)
 {
     GtkWidget *vbox;
     gchar *info;
-    
-    /* Create the new backup window */    
+
+    /* Create the new backup window */
     widgets->new_backup_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW(widgets->new_backup_window), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request(widgets->new_backup_window, 600, 200);
@@ -305,25 +311,25 @@ void create_new_backup_window(struct w *widgets)
 
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(widgets->new_backup_window), vbox);
-       
+
     /* Backup name entry inside a table and frame */
     GtkWidget *frame = gtk_frame_new(_("New Backup settings:"));
     GtkWidget *table = gtk_table_new(1, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), table);
 
-    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table), _(" Name of the new backup: "), 0,1,0,1, 300);
+    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table), _(" The name of the new backup: "), 0,1,0,1, 300);
 
     /* Apply and cancel buttons */
     GtkWidget *hbuttonbox = gtk_hbutton_box_new();
     gtk_box_pack_start(GTK_BOX(vbox), hbuttonbox, FALSE, FALSE, 0);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_SPREAD);
-            
+
     GtkWidget *cancel_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), cancel_button);
     g_signal_connect_swapped(G_OBJECT(cancel_button), "clicked", 
              G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(widgets->new_backup_window));
-                                                     
+
     GtkWidget *apply_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), apply_button);
     g_signal_connect_swapped(G_OBJECT(apply_button), "clicked", 
@@ -342,7 +348,7 @@ void create_rsync_tab(struct w *widgets)
     GtkCellRenderer *include_cell_renderer, *exclude_cell_renderer;
     GtkCellRenderer *incl_backup_cell_renderer, *delete_dest_cell_renderer;
     GtkCellRenderer *user_cell_renderer, *port_cell_renderer, *priv_key_path_cell_renderer;
-    GtkTreeViewColumn *col[8];
+    GtkTreeViewColumn *col[11];
     int colnr=0;
     int a=0, b=1;
     GtkWidget *frame;
@@ -380,7 +386,7 @@ void create_rsync_tab(struct w *widgets)
 						   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 						   G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_STRING,
 						   G_TYPE_STRING, G_TYPE_STRING);
-    
+
     widgets->backup_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->backup_treeview), GTK_TREE_MODEL(widgets->backup_store));
 
@@ -559,7 +565,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Spacer label */
     make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
 
     /* The settings... */
@@ -594,7 +600,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Spacer label */
     make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     GtkWidget *hbuttonbox2;
     hbuttonbox2 = gtk_hbutton_box_new();
@@ -661,16 +667,16 @@ void create_rsync_tab(struct w *widgets)
 
     /* Spacer label */
     make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* CRON Time schedule settings */
     widgets->schedule_check_button[0] = make_3columns_label_spin(GTK_TABLE(widgets->usr_set_table),
     _("Schedule this backup to run at specific times: "), 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* Hseparator */
     make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* Schedule (Month day = 1-31) */
     widgets->schedule_spin_button[0] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
@@ -690,7 +696,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Hseparator */
     make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* Schedule days */
     widgets->schedule_check_button[2] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
@@ -717,7 +723,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Hseparator */
     make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* Schedule hour   (0-23) */
     widgets->schedule_spin_button[1] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
@@ -744,15 +750,24 @@ void create_rsync_tab(struct w *widgets)
     a++; b++;
 
     /* Hseparator */
-//    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-//    a++; b++;				
+    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+    a++; b++;
+
+
+    /* Spacer label */
+    make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
+    a++; b++;
+
+    /* Backup at shutdown [x] */
+    widgets->backup_at_shutdown_check_button = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+                                                                            _("Backup at shutdown: "), 0, 1, a, b);
+    a++; b++;
 
-    // Backup at shutdown [X]
 
     /* Hseparator */
 //    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-//    a++; b++;				
-    
+//    a++; b++;
+
     // Pre for dumping databases, post for cleaning up etc...
     // Pre command  ( Commands to run before the source is backed up. )
     // Post command ( Commands to run after the backup. )
