@@ -56,6 +56,88 @@ gchar *sanitize_backup_name(gchar *backup_name)
 }
 
 
+gchar *mk_backup_script_path(gchar *backup_name)
+{
+    gchar *path, *bname;
+
+    bname = sanitize_backup_name(backup_name);
+
+    path = g_strdup_printf("%s/gadmin-rsync-%s.sh", global_scripts_dir, bname);
+
+    if( bname!=NULL )
+      g_free(bname);
+
+    return path;
+}
+
+
+gchar *mk_backup_at_shutdown_script_path(gchar *backup_name)
+{
+    gchar *path, *bname;
+
+    bname = sanitize_backup_name(backup_name);
+
+    path = g_strdup_printf("%s/K01gadmin-rsync-%s.sh", SYSTEM_SHUTDOWN_DIR, bname);
+
+    if( bname!=NULL )
+      g_free(bname);
+
+    return path;
+}
+
+
+/* Create a link to the backup script. Remove it first if it exists. */
+void add_to_system_shutdown(gchar *backup_name)
+{
+    gchar *shutdown_path, *backup_script_path, *info, *cmd;
+
+    /* Both paths are sanitized */
+    backup_script_path = mk_backup_script_path(backup_name);
+    shutdown_path = mk_backup_at_shutdown_script_path(backup_name);
+
+    remove_from_system_shutdown(backup_name);
+
+    cmd = g_strdup_printf("ln -s %s %s", backup_script_path, shutdown_path);
+    if( ! run_command(cmd) )
+    {
+	info = g_strdup_printf(_("Error: Unable to create a symlink to the backup script.\n"));
+	show_info(info);
+	g_free(info);
+    }
+    if( cmd!=NULL )
+      g_free(cmd);
+
+    if( backup_script_path!=NULL )
+      g_free(backup_script_path);
+    if( shutdown_path!=NULL )
+      g_free(shutdown_path);
+}
+
+
+/* Remove any existing links to this backup script */
+void remove_from_system_shutdown(gchar *backup_name)
+{
+    /* The path has been sanitized */
+    gchar *shutdown_path = mk_backup_at_shutdown_script_path(backup_name);
+
+    if( file_exists(shutdown_path) && strlen(shutdown_path) > 10 )
+      unlink(shutdown_path);
+
+    if( shutdown_path!=NULL )
+      g_free(shutdown_path);
+}
+
+
+gchar *mk_restore_script_path()
+{
+    /* No need to schedule the script. Using underscores
+       to differentiate from the backup scripts. */
+    gchar *path = g_strdup_printf("%s/gadmin_rsync_restore_script.sh", global_scripts_dir);
+
+    return path;
+}
+
+
 gchar *mk_log_path(gchar *backup_name)
 {
     gchar *path, *bname;
@@ -86,35 +168,19 @@ gchar *mk_extended_log_path(gchar *backup_name)
 }
 
 
-gchar *mk_script_path(gchar *backup_name)
-{
-    gchar *path, *bname;
-    
-    bname = sanitize_backup_name(backup_name);
-
-    path = g_strdup_printf("%s/gadmin-rsync-%s.sh", global_scripts_dir, bname);
-
-    if( bname!=NULL )
-      g_free(bname);
-
-    return path;
-}
-
-
 void schedule_cron(gchar *cron_line, gchar *backup_name)
 {
     gchar *cmd, *info, *script_path;
 
-    script_path = mk_script_path(backup_name);
+    script_path = mk_backup_script_path(backup_name);
 
     /* Delete matching cron line */
     del_cron(script_path);
 
     /* Add this cron line */
     add_cron(cron_line, script_path);
-    
-    g_free(script_path);
 
+    g_free(script_path);
 
     /* Send a HUP to crond so it rereads crontab */
     cmd = g_strdup_printf("%s", CROND_REREAD_CMD);
@@ -150,7 +216,7 @@ void del_cron(gchar *script_path)
     long file_size = 0;
     char *line, *new_buffer, *path_buffer;
     int i = 0, found_path = 0;
-    
+
     /* Read crontab file, get everything but the line with this script_path */
     if((fp=fopen(CRONTAB_PATH, "r"))==NULL)
     {
@@ -160,14 +226,14 @@ void del_cron(gchar *script_path)
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
-                                        
+
     line = allocate(file_size+1);
     new_buffer = allocate(file_size+1);
     path_buffer = allocate(file_size+1);
-                                                    
+
     if( file_size > 1 )
     while(fgets(line, file_size, fp)!=NULL)
-    {                                 
+    {
 	for(i=0; line[i]!='\0'; i++)
 	{
 	    if( line[i]=='/' )
@@ -187,7 +253,7 @@ void del_cron(gchar *script_path)
     	    	    path_buffer[i]='\0';
     	        if( path_buffer[i]=='\r' )
     	    	    path_buffer[i]='\0';
-	    }    	    	
+	    }
 
 	    /* We have found our cron line */
 	    if( strcmp(path_buffer, script_path) == 0 )
