@@ -18,14 +18,18 @@
 */
 
 
-
 #ifndef CRON_FUNCTIONS_H
 #define CRON_FUNCTIONS_H
 
 gchar *sanitize_backup_name(gchar *backup_name);
+gchar *mk_backup_script_path(gchar *backup_name);
+gchar *mk_backup_at_shutdown_script_path(gchar *backup_name);
+gchar *mk_restore_script_path();
 gchar *mk_log_path(gchar *backup_name);
 gchar *mk_extended_log_path(gchar *backup_name);
-gchar *mk_script_path(gchar *backup_name);
+
+void add_to_system_shutdown(gchar *backup_name);
+void remove_from_system_shutdown(gchar *backup_name);
 
 void schedule_cron(gchar *cron_line, gchar *backup_name);
 void add_cron(gchar *cron_line, gchar *script_path);
