@@ -102,14 +102,15 @@ int run_ssh_cmd(char *new_argv[], char *password)
 {
     /* Create a pseudo terminal and fork the process */
     int i, masterpty, slavepty, childpid, child_status = 0;
-    int retval_select =  0; /* -1 = Error */
-    int child_exit    =  0; /*  1 = Child exited */
+    int retval_select =  0; /* -1 = Error. */
+    int child_exit    =  0; /*  1 = Child exited. */
+    int cmd_ret       =  0; /* Command return value. */
     pid_t wait_pid;
     const char *slave_pty_name;
     const char *askpass = "SSH_ASKPASS";
     const char *display = "DISPLAY";
 
-    masterpty = getpt();
+    masterpty = posix_openpt(O_RDWR|O_NOCTTY);
     if( masterpty == -1 )
     {
 	perror("Can not open a pseudo-terminal master");
@@ -147,7 +148,7 @@ int run_ssh_cmd(char *new_argv[], char *password)
 	   fprintf(stderr, "%s ", new_argv[i]);
 	fprintf(stderr, "\n");
 
-	/* Unset SSH_ASKPASS and DISPLAY to disable GNOME ssh-askpass popup. */
+	/* Unset SSH_ASKPASS and DISPLAY to disable ssh-askpass popup. */
 	if( unsetenv(askpass) == -1 )
           fprintf(stderr, "Unable to unset SSH_ASKPASS environment variable.\n");
 	if( unsetenv(display) == -1 )
@@ -156,7 +157,7 @@ int run_ssh_cmd(char *new_argv[], char *password)
 	/* Run the command */
 	execvp(new_argv[0], new_argv);
 
-	fprintf(stderr, "Can not run command.\n");
+	fprintf(stderr, "Could not run command.\n");
 
 	exit(errno);
     }
@@ -186,7 +187,7 @@ int run_ssh_cmd(char *new_argv[], char *password)
 		    {
 			/* Process error. Close the master control pty for the process. */
 			close(masterpty);
-			child_exit = 1;
+			break;
 		    }
 		}
 	    }
@@ -199,12 +200,14 @@ int run_ssh_cmd(char *new_argv[], char *password)
 
     /* Child has exited, return child status */
 
-    /* Command successful. */
-    if( WIFEXITED(child_status) )
-        return 1;
+    cmd_ret = (child_status & 0xff00) >> 8;
 
-    /* Command failed or timed out. */
-    return 0;
+    if( cmd_ret == 0 )
+      cmd_ret = 1;
+    else
+      cmd_ret = 0;
+
+    return cmd_ret;
 }
 
 
@@ -243,21 +246,21 @@ int handle_output(int fd, char *password)
     char pass_line[]="assword:";
     char pass_phrase_line[]="passphrase";
     char key_overwrite_line[]="verwrite (y/n)";
-    int  retval = 1; /* 0 = Exit child process due to read or write error */
+    int  retval = 1; /* 0 = Exit child process due to denial or write error */
     char output[128]="";
     char line[128]="";
-    int i=0, x=0, bytes_read=0;
+    int  i=0, x=0, num_pass_tries=0, bytes_read=0;
     
     bytes_read = read(fd, output, sizeof(output));
 
-    /* Read error */
+    /* Nothing to read. Return OK. */
     if( bytes_read == -1 )
-      return 0;
+      return 1;
 
 
-    for(i=0; i<=129; i++)
+    for(i=0; i<=128; i++)
     {
-	line[x]=output[i];
+	line[x] = output[i];
 	x++;
 	
 	if( output[i]!='\0' && output[i]!='\r' && output[i]!='\n' )
@@ -270,28 +273,50 @@ int handle_output(int fd, char *password)
 	{
 	    fprintf(stderr, "Overwriting old keys.\n");
 	    if( ! write_string(fd, "yes") )
-	      retval = 0;
+	    {
+	        retval = 0;
+		break;
+	    }
 	}
 
 	if( strstr(line, pass_phrase_line) )
 	{
 	    fprintf(stderr, "Writing empty key phrase.\n");
 	    if( ! write_string(fd, "\n") )
-	      retval = 0;
+	    {
+	        retval = 0;
+	        break;
+	    }
 	}
 
 	if( strstr(line, auth_line) )
 	{
 	    fprintf(stderr, "Allowing authentication to proceed.\n");
 	    if( ! write_string(fd, "yes") )
-	      retval = 0;
+	    {
+	        retval = 0;
+	        break;
+	    }
 	}
 
 	if( strstr(line, pass_line) )
 	{
 	    fprintf(stderr, "Supplying password.\n");
 	    if( ! write_string(fd, password) )
-	      retval = 0;
+	    {
+	        retval = 0;
+	        break;
+	    }
+
+// Must be global...
+	    num_pass_tries++;
+	    
+	    if( num_pass_tries > 2 )
+	    {
+		fprintf(stderr, "Error: Wrong password.\n");
+		retval = 0;
+		break;
+	    }
 	}
 
 	x = 0;
