@@ -39,12 +39,12 @@ extern gchar *global_key_path;
 extern G_CONST_RETURN gchar *global_home_dir;
 
 
-
-void setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *type, gchar *len, struct w *widgets)
+/* Create keys and on success install them to the remote computer */
+int setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *type, gchar *len, struct w *widgets)
 {
     gchar *info;
+    int retval = 0;
 
-    /* Create keys and on success install them to the specified remote computer */
     if( is_empty(user) || is_empty(password) || is_empty(host)
     ||  is_empty(port) || is_empty(type) || is_empty(len) )
     {
@@ -52,21 +52,27 @@ void setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *t
 	show_info(info);
 	if( info!=NULL )
 	  g_free(info);
-	return;    
+
+	return retval;    
     }
 
     if( ! generate_keys(user, host, type, len, widgets) )
     {
-// Naah...        printf("Key already exists or keygen failed.\n");
+	// Naah... printf("Key already exists or keygen failed.\n");
+
+	return retval;
     }
     else
     {
         /* Upload key to remote host and install them there */
         if( ! install_remote_key(user, host, port, password, widgets) )
 	{
-// Showing errors from the functions instead   	    printf("Key upload failed.\n");
+	    // Naah...  printf("Key upload failed.\n");
+	    return retval;
 	}
     }
+
+    return 1;
 }
 
 
@@ -182,7 +188,7 @@ int generate_keys(gchar *user, gchar *host, gchar *key_type, gchar *key_len, str
 }
 
 
-/* Upload public key to remote host and append it to file: /HOME/USERNAME/.ssh/authorized_keys */
+/* Upload public key to remote host and append it to file: ~/.ssh/authorized_keys */
 int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, struct w *widgets)
 {
     FILE *fp;
@@ -279,44 +285,27 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 
 
     /* Upload public key and key install script to the remote server */
-//    gchar *user_host_dir = g_strdup_printf("%s@%s:%s/", user, host, global_home_dir);
-    /* (Now using tilde ~ instead of what will otherwise always be the root dir) */
     gchar *user_host_dir = g_strdup_printf("%s@%s:~", user, host);
 
     new_argv = create_scp_upload_cmd(user, port, key_path_pub, script_path, user_host_dir);
 
     if( ! run_ssh_cmd(new_argv, password) )
     {
-	info = g_strdup_printf(_("Error: Can not upload public key to the remote host.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
-
 	printf("Error uploading key.\n");
 	g_free(script_path);
 	g_free(key_path_pub);
 	g_free(user_host_dir);
 	g_free(script_name);
 	free(new_argv);
+
 	return retval;
     }
-    else
-      {
-/* No.
-	    info = g_strdup_printf(_("Public key upload to remote host successful.\n"));
-	    show_info(info);
-	    if( info!=NULL )
-	      g_free(info);
-*/      
-    	    printf("Key upload successful.\n");
-      }
 
     free(new_argv);
     g_free(user_host_dir);
 
 
     /* Create the key install command */
-//    gchar *ssh_cmd = g_strdup_printf("chmod 755 %s && sh %s && rm -f %s", script_path, script_path, script_path);
     gchar *ssh_cmd = g_strdup_printf("chmod 755 ~/%s && sh ~/%s && rm -f ~/%s", script_name, script_name, script_name);
     
     new_argv = create_ssh_cmd(user, host, port, ssh_cmd);
@@ -347,6 +336,7 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 	  g_free(info);
 
         printf("Key installation successful.\n");
+
 	retval = 1;
     }
 
