@@ -31,7 +31,7 @@ int key_exists(gchar *key_name);
 
 int is_empty(gchar *input);
 
-void setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *type, gchar *len, struct w *widgets);
+int setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *type, gchar *len, struct w *widgets);
 int generate_keys(gchar *user, gchar *host, gchar *key_type, gchar *key_len, struct w *widgets);
 int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, struct w *widgets);
 
