@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,6 @@ void make_3columns_hseparator(GtkTable *table,
     GtkWidget *hsep;
 
     hsep = gtk_hseparator_new();
-    gtk_table_attach(table, hsep, left_attach, right_attach + 3, top_attach, bottom_attach, GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(table, hsep, left_attach, right_attach + 3, top_attach, bottom_attach, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 5, 5);
     gtk_widget_show(hsep);
 }
