@@ -147,6 +147,9 @@ void populate_rsync_tab(struct w *widgets)
     /* Set it to any month by default */
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1]), TRUE);
 
+    /* Set backup at shutdown to off by default */
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_at_shutdown_check_button), FALSE);
+
     /* Populate the backup combo */
     if( populate_backup_combo(widgets) )
     {
@@ -185,7 +188,7 @@ void populate_rsync_tab(struct w *widgets)
 	if( strlen(line) > 16384 )
 	  continue;
 
-	if( ! strstr(line,"schedule_") ) 
+	if( ! strstr(line,"schedule_") )
 	{
 	    /* Append a row once if the data length is valid */
 	    if( ! one_time && strlen(line) > 3 )
@@ -306,6 +309,12 @@ void populate_rsync_tab(struct w *widgets)
 	}
 
 
+	/* Is backup scheduled at shutdown... */
+	if( strstr(line, "schedule_backup_at_computer_shutdown:") )
+	{
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_at_shutdown_check_button), TRUE);
+	}
+
 	/* Is scheduling used... */
 	if( strstr(line, "schedule_") )
 	{
