@@ -49,7 +49,7 @@ int has_value(gchar *input)
 
     if( input!=NULL && strlen(input) > 0 )
       ret = 1;
-      
+
     return ret;
 }
 
@@ -104,7 +104,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
     /* Get include in backup checkbox value */
     gtk_tree_model_get(model, iter, 6, &include_in_backup_script, -1);
 
-    /* Get include in backup checkbox value */
+    /* Get "del dest not in source" checkbox value */
     gtk_tree_model_get(model, iter, 7, &del_dst_not_in_src, -1);
 
     /* Get user */
@@ -122,9 +122,9 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	{
 	    error_src_dst_info = 0; /* Dont show this again */
 	    info = g_strdup_printf(_("Error: This backup is missing a required source or destination path.\n"));
-    	    show_info(info);
-    	    g_free(info);
-    	}
+	    show_info(info);
+	    g_free(info);
+	}
     }
 
     /* Rsync cant do server to server backups */
@@ -134,9 +134,9 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	{
 	    error_server_server_info = 0;
 	    info = g_strdup_printf(_("Error: Server to server backups are not supported by rsync.\n"));
-    	    show_info(info);
-    	    g_free(info);
-    	}
+	    show_info(info);
+	    g_free(info);
+	}
     }
 
     /* Open the settings file for appending */
@@ -222,7 +222,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
     setting = g_strdup_printf("del_dst_files_value %d\n\n", del_dst_not_in_src);
     fputs(setting, fp);
     g_free(setting);
-    
+
     /* Close the settings file */
     fclose(fp);
 
@@ -242,7 +242,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 
 
     /* Open the backup script file for appending */
-    script_file = mk_script_path(global_backup_name);
+    script_file = mk_backup_script_path(global_backup_name);
     if((fp=fopen(script_file, "a"))==NULL)
     {
 	info = g_strdup_printf(_("Error: Can not write backup script here:\n%s\n"), script_file);
@@ -508,7 +508,7 @@ void save_backup_settings(struct w *widgets)
     gchar *cmd, *info, *settings_file, *script_path, *script, *cron_line;
     char *script_days = NULL;
     G_CONST_RETURN gchar *script_month_day = NULL, *script_hour = NULL, *script_minute = NULL;
-    
+
     /* Only show one error popup per error type */
     error_src_dst_info       = 1;
     error_server_server_info = 1;
@@ -525,7 +525,7 @@ void save_backup_settings(struct w *widgets)
     }
 
     /* Remove cron lines matching this backup from crontab */
-    script_path = mk_script_path(global_backup_name);
+    script_path = mk_backup_script_path(global_backup_name);
     if( script_path == NULL || strlen(script_path) < 3 )
     {
 	info = g_strdup_printf(_("Error: script path too short.\n"));
@@ -542,20 +542,43 @@ void save_backup_settings(struct w *widgets)
     /* Make sure we have a script file before we begin appending to it */
     if((fp=fopen(script_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error: Can not write backup script here:\n%s\n"), script_path);
+	info = g_strdup_printf(_("Error: Can not write the backup script here:\n%s\n"), script_path);
         show_info(info);
         g_free(info);
-
         g_free(script_path);
         return;
     }
-    script = g_strconcat("#!/bin/sh\n\n", NULL);
-    fputs(script, fp);
-    if( script!=NULL )
-      g_free(script);
 
+    /* Fedora etc requires a lock file as: /var/lock/sybsys/ScriptName
+       Otherwise "Backup at shutdown" scripts will be terminated by killall and halt scripts. */
+
+    /* Backup at computer shutdown */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_at_shutdown_check_button)) )
+    {
+	script = g_strconcat("#!/bin/sh\n\n",
+	"### Add RedHat and Fedora Lockfiles for backup at shutdown ###\n",
+	"if [ -d /var/lock/subsys ]; then\n",
+	"   touch /var/lock/subsys/gadmin-rsync-", global_backup_name, ".sh\n",
+	"   touch /var/lock/subsys/rsync\n",
+	"else\n",
+	"### Add Debian and Ubuntu Lockfiles for backup at shutdown ###\n",
+	"if [ -d /var/lock ]; then\n",
+	"   touch /var/lock/gadmin-rsync-", global_backup_name, ".sh\n",
+	"   touch /var/lock/rsync\n",
+	"fi\n",
+	"fi\n\n",
+	NULL);
+    }
+    else
+    {
+	script = g_strconcat("#!/bin/sh\n\n",
+	NULL);
+    }
+    fputs(script, fp);
     fclose(fp);
 
+    if( script!=NULL )
+      g_free(script);
 
     /* Chmod the script file to 755 so cron can run it. */
     cmd = g_strdup_printf("chmod 755 \"%s\"", script_path);
@@ -568,8 +591,6 @@ void save_backup_settings(struct w *widgets)
     }
     if( cmd!=NULL )
       g_free(cmd);
-    if( script_path!=NULL )
-      g_free(script_path);
 
 
     /* Create an an empty settings file before we begin appending to it */
@@ -580,6 +601,7 @@ void save_backup_settings(struct w *widgets)
         show_info(info);
         g_free(info);
         g_free(settings_file);
+        g_free(script_path);
         return;
     }
     fclose(fp);
@@ -589,25 +611,76 @@ void save_backup_settings(struct w *widgets)
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->backup_store), (GtkTreeModelForeachFunc) save_foreach, widgets);
 
 
-    /* Return if scheduling is disabled */
-    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0])) )
+    /* Backup at computer shutdown */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_at_shutdown_check_button)) )
     {
-	/* The cron line has already been removed */
-	g_free(settings_file);
-	return;
+	/* Append lock file removal to the end of the backup script. */
+	if((fp=fopen(script_path, "a"))==NULL)
+	{
+	    info = g_strdup_printf(_("Error: Can not write the backup script here:\n%s\n"), script_path);
+	    show_info(info);
+	    g_free(info);
+	    g_free(script_path);
+	    return;
+	}
+	script = g_strconcat("#!/bin/sh\n\n",
+	"### Remove RedHat and Fedora Lockfiles for backup at shutdown ###\n",
+	"if [ -f /var/lock/subsys/gadmin-rsync-", global_backup_name, ".sh ]; then\n",
+	"   rm -f /var/lock/subsys/gadmin-rsync-", global_backup_name, ".sh\n",
+	"   rm -f /var/lock/subsys/rsync\n",
+	"fi\n",
+	"### Remove Debian and Ubuntu Lockfiles for backup at shutdown ###\n",
+	"if [ -f /var/lock/gadmin-rsync-", global_backup_name, ".sh ]; then\n",
+	"   rm -f /var/lock/gadmin-rsync-", global_backup_name, ".sh\n",
+	"   rm -f /var/lock/rsync\n",
+	"fi\n\n",
+	NULL);
+
+	fputs(script, fp);
+	fclose(fp);
+	if( script!=NULL )
+	  g_free(script);
     }
 
+    g_free(script_path);
+
+
     /* Append shedule_month, schedule_days and schedule_time values last in the settings file */
     if((fp=fopen(settings_file, "a"))==NULL)
     {
 	info = g_strdup_printf(_("Error: Can not write backup schedule here:\n%s\n"), settings_file);
         show_info(info);
         g_free(info);
-
         g_free(settings_file);
         return;
     }
 
+    /* Backup at computer shutdown */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_at_shutdown_check_button)) )
+    {
+        fputs("schedule_backup_at_computer_shutdown: yes\n", fp);
+
+	/* Write a "Backup at shutdown" script in the SYSTEM_SHUTDOWN_DIR */
+	add_to_system_shutdown(global_backup_name);
+	
+    }
+    else
+    {
+	/* Remove this shutdown at backup script if it exists */
+	remove_from_system_shutdown(global_backup_name);
+    }
+
+
+    /* Return if scheduling is disabled */
+    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0])) )
+    {
+	/* The cron line has already been removed */
+	g_free(settings_file);
+	
+	fclose(fp);
+	return;
+    }
+
     script_month_day = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[0]));
     /* Run every month is selected */
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1])) )
@@ -681,7 +754,7 @@ void save_backup_settings(struct w *widgets)
         fputs("schedule_every_minute\n", fp);
         script_minute = g_strdup_printf("%s", "*");
     }
-    
+
     /* Close the settings file */
     fclose(fp);
     g_free(settings_file);
