@@ -43,6 +43,7 @@ void set_version(struct w *widgets)
     gchar *ver=NULL;
     gchar *utf8=NULL;
     gchar *info;
+    GdkColor color;
 
     /* Rsync check */
     command = g_strdup_printf("%s --version 2>&1", RSYNC_BINARY);
@@ -92,6 +93,11 @@ void set_version(struct w *widgets)
 	utf8 = g_locale_to_utf8(ver, strlen(ver), NULL, NULL, NULL);
         gtk_label_set_text(GTK_LABEL(widgets->version_label), utf8);
 	g_free(utf8);
+
+	/* Set status color */
+	gdk_color_parse("red", &color);
+	gtk_widget_modify_fg(widgets->version_label, GTK_STATE_NORMAL, &color);
     }    
+
     g_free(ver);
 }
