@@ -61,31 +61,51 @@ void show_help()
   gtk_text_view_set_right_margin (GTK_TEXT_VIEW (help_textview), 10);
 
   help_text = g_strconcat(
-  
-  _("\n\n\t\t\tHow to backup using GAdmin-Rsync:\n\n"),
+  _("\n\n\t\tHow to backup and restore using GAdmin-Rsync.\n\n\n"),
 
-  _("Pressing the \"Add new backup\" button will add a new backup.\n"),
+  _("1. Backing up data:\n\n"),
+
+  _("Pressing the \"Create new backup\" button creates and adds a new backup.\n"),
   _("When this is done the \"Add backup data\" button can be used to\n"),
   _("specify what type of backups to include in the new backup, such as:\n"),
-  _("Remote to local, local to remote or local to local backups.\n"),
+  _("remote to local, local to remote or local to local backups.\n"),
   _("The backups can be started manually with \"Run selected backup.\"\n"),
-  _("The progress of the backup can be viewed in the backup progress tab.\n"),
+  _("The progress of the backup can be viewed in the progress tab.\n\n"),
 
-  _("\nWhen everything is working as expected the backups can be\n"),
+  _("When everything is working as expected the backups can be\n"),
   _("scheduled to run at specific times using cron.\n"),
+  _("Backups can also be scheduled to run at system shutdown.\n"),
+  _("The backups will not be run if the system is rebooted.\n\n"),
 
-  _("\nRemote backups are differential and encrypted.\n"),
+  _("Logs and extended logs are kept for all backups.\n"),
+  _("They can be viewed by clicking on \"Show backup log\" for each backup.\n\n\n"),
+
+
+  _("2. Restoring data:\n\n"),
+
+  _("Pressing the \"Restore from selection\" button shows a restore menu that\n"),
+  _("contains relevant source and destination paths depending on the restore type.\n"),
+  _("The paths shown are the reverse of the backups.\n"),
+  _("Local source and destination paths can be browsed and re-selected.\n"),
+  _("A slash last in source paths means transfer the content of\n"),
+  _("the directory, IE: \"/path/\" means \"/path/*\".\n"),
+  _("Press the \"Forward\" button when satisfied with the restore selection.\n"),
+  _("The progress of the restore can be viewed in the progress tab.\n\n\n"),
+
+
+  _("3. Technical specifications for backing up and restoring data:\n\n"),
+
+  _("Remote backups and restores are differential and encrypted.\n"),
   _("This is achieved by using rsync over ssh.\n"),
   _("Keys are automatically created and installed on\n"),
   _("remote hosts using ssh-keygen, scp and ssh.\n"),
   _("For this to work the remote hosts must be running ssh servers.\n"),
-
-  _("\nLogs and extended logs are kept for all backups.\n"),
-  _("They can be viewed by clicking on \"Show backup log\".\n"),
+  _("The data is backed up or restored as the selected username.\n"),
 
 
   _("\nVisit http://www.gadmintools.org\n"), 
   NULL);
+
   gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(help_textview)), help_text, -1);
 
   if( help_text!=NULL )
