@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,11 @@
 
 extern struct w *widgets;
 
-void show_log(struct w *widgets);
+void show_log_window(struct w *widgets);
 void populate_log(struct w *widgets);
 void delete_log(struct w *widgets);
 
+void show_extended_log_window(struct w *widgets);
+void populate_extended_log(struct w *widgets);
+
 #endif
