@@ -96,11 +96,11 @@ char * get_process_pid(char process[1024])
 }
 
 
-
 int status_update(struct w *widgets)
 {
     char *pid;
     gchar *info, *utf8=NULL;
+    GdkColor color;
 
     /* Check if rsync backup is running */
     pid = get_process_pid("rsync");
@@ -142,6 +142,19 @@ int status_update(struct w *widgets)
     if( utf8!=NULL )
       g_free(utf8);
 
+    if( client_active )
+    {
+	/* Set status color */
+	gdk_color_parse("dark green", &color);
+	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
+    }
+    else
+    {
+	/* Set status color */
+	gdk_color_parse("red", &color);
+	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
+    }
+
     g_free(info);
 
     return (TRUE);
