@@ -38,11 +38,12 @@ typedef struct w
   GtkWidget *main_window;
   GtkWidget *main_vbox;
 
+  GtkWidget *main_notebook;
   GtkWidget *notebook_vbox1;
   GtkWidget *notebook_vbox2;
   GtkWidget *notebook_vbox3;
   GtkWidget *notebook_vbox4;
-  
+
   GtkWidget *status_label;
   GtkWidget *version_label;
 
@@ -56,6 +57,7 @@ typedef struct w
 
   GtkWidget *schedule_check_button[11];
   GtkWidget *schedule_spin_button[3];
+  GtkWidget *backup_at_shutdown_check_button;
 
   GtkWidget *rsync_set_entry[4];
   GtkWidget *rsync_set_combo[2];
@@ -72,7 +74,7 @@ typedef struct w
   GtkWidget *backup_chkbtn_local_remote;
   GtkWidget *backup_chkbtn_remote_local;
 
-  /* The server menu window */
+  /* The backup server menu window */
   GtkWidget *server_menu_window;
   GtkWidget *remote_server_entry;
   GtkWidget *remote_path_entry;
@@ -81,7 +83,21 @@ typedef struct w
   GtkWidget *remote_port_entry;
   GtkWidget *key_type_combo;
   GtkWidget *key_length_spinbutton;
-  
+
+
+  /* Restore widgets */
+  GtkWidget *restore_menu_window;
+  GtkWidget *restore_src_server_entry;
+  GtkWidget *restore_src_path_entry;
+  GtkWidget *restore_dst_server_entry;
+  GtkWidget *restore_dst_path_entry;
+  GtkWidget *restore_dst_user_entry;
+  GtkWidget *restore_dst_port_entry;
+
+  GtkWidget *restore_test_only_checkbutton;
+  GtkWidget *restore_src_filesel;
+  GtkWidget *restore_dst_filesel;
+
   /* The log window */
   GtkWidget *log_window;
   GtkWidget *log_treeview;
